@@ -21,6 +21,8 @@ Solid::Battery::Battery(QObject *backendObject)
 
     connect(backendObject, SIGNAL(capacityChanged(int, QString)), this, SIGNAL(capacityChanged(int, QString)));
 
+    connect(backendObject, SIGNAL(cycleCountChanged(int, QString)), this, SIGNAL(cycleCountChanged(int, QString)));
+
     connect(backendObject, SIGNAL(powerSupplyStateChanged(bool, QString)), this, SIGNAL(powerSupplyStateChanged(bool, QString)));
 
     connect(backendObject, SIGNAL(chargeStateChanged(int, QString)), this, SIGNAL(chargeStateChanged(int, QString)));
@@ -72,6 +74,12 @@ int Solid::Battery::capacity() const
     return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), 100, capacity());
 }
 
+int Solid::Battery::cycleCount() const
+{
+    Q_D(const Battery);
+    return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), -1, cycleCount());
+}
+
 bool Solid::Battery::isRechargeable() const
 {
     Q_D(const Battery);
@@ -144,21 +152,6 @@ double Solid::Battery::temperature() const
     return_SOLID_CALL(Ifaces::Battery *, d->backendObject(), 0.0, temperature());
 }
 
-bool Solid::Battery::isRecalled() const
-{
-    return false;
-}
-
-QString Solid::Battery::recallVendor() const
-{
-    return QString();
-}
-
-QString Solid::Battery::recallUrl() const
-{
-    return QString();
-}
-
 QString Solid::Battery::serial() const
 {
     Q_D(const Battery);
